@@ -126,7 +126,7 @@ class AnsiblePlaybook:
             warnings.filterwarnings("default", category=MoleculeRuntimeWarning)
             self._config.driver.sanity_checks()
             cwd = self._config.scenario_path
-            result = util.run_command(
+            result = self._config.app.run_command(
                 cmd=self._ansible_command,
                 env=self._env,
                 debug=self._config.debug,
@@ -137,7 +137,7 @@ class AnsiblePlaybook:
             from rich.markup import escape
 
             util.sysexit_with_message(
-                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",  # noqa: E501
+                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",
                 result.returncode,
                 warns=warns,
             )
