@@ -28,7 +28,6 @@ import re
 import sys
 
 from pathlib import Path
-from subprocess import CalledProcessError, CompletedProcess
 from typing import TYPE_CHECKING, overload
 
 import jinja2
@@ -37,7 +36,6 @@ import yaml
 from ansible_compat.ports import cache
 from rich.syntax import Syntax
 
-from molecule.app import app
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
 
@@ -153,53 +151,6 @@ def sysexit_with_message(
     sysexit(code)
 
 
-def run_command(  # noqa: PLR0913
-    cmd: str | list[str],
-    env: dict[str, str] | None = None,
-    cwd: Path | None = None,
-    *,
-    debug: bool = False,
-    echo: bool = False,  # noqa: ARG001
-    quiet: bool = False,  # noqa: ARG001
-    check: bool = False,
-) -> CompletedProcess[str]:
-    """Execute the given command and returns None.
-
-    Args:
-        cmd: A list of strings containing the command to run.
-        env: A dict containing the shell's environment.
-        cwd: An optional Path to the working directory.
-        debug: An optional bool to toggle debug output.
-        echo: An optional bool to toggle command echo.
-        quiet: An optional bool to toggle command output.
-        check: An optional bool to toggle command error checking.
-
-    Returns:
-        A completed process object.
-
-    Raises:
-        CalledProcessError: If return code is nonzero and check is True.
-    """
-    if debug:
-        print_environment_vars(env)
-
-    result = app.runtime.run(
-        args=cmd,
-        env=env,
-        cwd=cwd,
-        tee=True,
-        set_acp=False,
-    )
-    if result.returncode != 0 and check:
-        raise CalledProcessError(
-            returncode=result.returncode,
-            cmd=result.args,
-            output=result.stdout,
-            stderr=result.stderr,
-        )
-    return result
-
-
 def os_walk(
     directory: str | Path,
     pattern: str,
@@ -402,7 +353,7 @@ def abs_path(path: str | Path | None) -> str | Path:
     """Return absolute path.
 
     Args:
-        path: File path to resolve absolute path from.
+        path: File path to create absolute path from.
 
     Returns:
         Absolute path of path.
@@ -411,9 +362,9 @@ def abs_path(path: str | Path | None) -> str | Path:
         return ""
 
     output_type = type(path)
-    if isinstance(path, str):
-        path = Path(path)
-    path = path.resolve()
+    if isinstance(path, Path):
+        path = str(path)
+    path = os.path.abspath(path)  # noqa: PTH100
 
     return output_type(path)
 
@@ -551,7 +502,7 @@ def boolean(value: bool | AnyStr, *, strict: bool = True) -> bool:
         return False
 
     raise TypeError(  # noqa: TRY003
-        f"The value '{value!s}' is not a valid boolean.  Valid booleans include: {', '.join(repr(i) for i in BOOLEANS)!s}",  # noqa: EM102, E501
+        f"The value '{value!s}' is not a valid boolean.  Valid booleans include: {', '.join(repr(i) for i in BOOLEANS)!s}",  # noqa: EM102
     )
 
 
@@ -597,3 +548,24 @@ def print_as_yaml(data: object) -> None:
     # https://github.com/Textualize/rich/discussions/990#discussioncomment-342217
     result = Syntax(code=safe_dump(data), lexer="yaml", background_color="default")
     console.print(result)
+
+
+def oxford_comma(listed: Iterable[bool | str | Path], condition: str = "and") -> str:
+    """Format a list into a sentence.
+
+    Args:
+        listed: List of string entries to modify
+        condition: String to splice into string, usually 'and'
+
+    Returns:
+        Modified string
+    """
+    match [f"'{entry!s}'" for entry in listed]:
+        case [one]:
+            return one
+        case [one, two]:
+            return f"{one} {condition} {two}"
+        case [*front, back]:
+            return f"{', '.join(s for s in front)}, {condition} {back}"
+        case _:
+            return ""
