@@ -24,8 +24,18 @@ import glob
 import logging
 import os
 
+from collections.abc import MutableMapping
+from pathlib import Path
+from typing import TYPE_CHECKING, cast
+
 from molecule import util
-from molecule.api import Verifier  # type: ignore[attr-defined]
+from molecule.api import Verifier
+
+
+if TYPE_CHECKING:
+
+    from molecule.config import Config
+    from molecule.verifier.base import Schema
 
 
 LOG = logging.getLogger(__name__)
@@ -89,23 +99,33 @@ class Testinfra(Verifier):
     .. _`Testinfra`: https://testinfra.readthedocs.io
     """
 
-    def __init__(self, config=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
+    def __init__(self, config: Config) -> None:
         """Set up the requirements to execute ``testinfra`` and returns None.
 
         Args:
             config: An instance of a Molecule config.
         """
         super().__init__(config)
-        self._testinfra_command = None
+        self._testinfra_command: list[str] = []
         self._tests = []  # type: ignore[var-annotated]
 
     @property
-    def name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def name(self) -> str:
+        """Name of the verifier.
+
+        Returns:
+            The name of the verifier.
+        """
         return "testinfra"
 
     @property
-    def default_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
-        d = self._config.driver.testinfra_options
+    def default_options(self) -> MutableMapping[str, str | bool]:
+        """Get default CLI arguments provided to ``cmd``.
+
+        Returns:
+            The default verifier options.
+        """
+        d = cast(MutableMapping[str, str | bool], self._config.driver.testinfra_options)
         d["p"] = "no:cacheprovider"
         if self._config.debug:
             d["debug"] = True
@@ -118,24 +138,41 @@ class Testinfra(Verifier):
     # NOTE(retr0h): Override the base classes' options() to handle
     # ``ansible-galaxy`` one-off.
     @property
-    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def options(self) -> MutableMapping[str, str | bool]:
+        """The computed options for this verifier.
+
+        Returns:
+            The combined dictionary of default options and those specified in the config.
+        """
         o = self._config.config["verifier"]["options"]
         # NOTE(retr0h): Remove verbose options added by the user while in
         # debug.
         if self._config.debug:
-            o = util.filter_verbose_permutation(o)  # type: ignore[no-untyped-call]
+            o = util.filter_verbose_permutation(o)
 
         return util.merge_dicts(self.default_options, o)
 
     @property
-    def default_env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
-        env = util.merge_dicts(os.environ, self._config.env)
-        env = util.merge_dicts(env, self._config.provisioner.env)
+    def default_env(self) -> dict[str, str]:
+        """Get default env variables provided to ``cmd``.
 
-        return env  # noqa: RET504
+        Returns:
+            The default verifier environment variables.
+        """
+        env = cast(dict[str, str], os.environ)
+        env = util.merge_dicts(env, self._config.env)
+        if self._config.provisioner:
+            env = util.merge_dicts(env, self._config.provisioner.env)
+
+        return env
 
     @property
-    def additional_files_or_dirs(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def additional_files_or_dirs(self) -> list[str]:
+        """Additional paths related to the verifier.
+
+        Returns:
+            List of files and directories to use with this verifier.
+        """
         files_list = []
         c = self._config.config
         for f in c["verifier"]["additional_files_or_dirs"]:
@@ -147,27 +184,32 @@ class Testinfra(Verifier):
 
         return files_list
 
-    def bake(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
-        """Bake a ``testinfra`` command so it's ready to execute and returns None."""
+    def bake(self) -> None:
+        """Bake a ``testinfra`` command so it's ready to execute."""
         options = self.options
-        verbose_flag = util.verbose_flag(options)  # type: ignore[no-untyped-call]
+        verbose_flag = util.verbose_flag(options)
         args = verbose_flag
 
-        self._testinfra_command = [  # type: ignore[assignment]
+        self._testinfra_command = [
             "pytest",
             *util.dict2args(options),
             *self._tests,
             *args,
         ]
 
-    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, D102
+    def execute(self, action_args: list[str] | None = None) -> None:
+        """Execute ``cmd``.
+
+        Args:
+            action_args: list of arguments to be passed.
+        """
         if not self.enabled:
             msg = "Skipping, verifier is disabled."
             LOG.warning(msg)
             return
 
         if self._config:
-            self._tests = self._get_tests(action_args)  # type: ignore[no-untyped-call]
+            self._tests = self._get_tests(action_args)
         else:
             self._tests = []
         if not len(self._tests) > 0:
@@ -175,16 +217,16 @@ class Testinfra(Verifier):
             LOG.warning(msg)
             return
 
-        self.bake()  # type: ignore[no-untyped-call]
+        self.bake()
 
         msg = f"Executing Testinfra tests found in {self.directory}/..."
         LOG.info(msg)
 
-        result = util.run_command(
-            self._testinfra_command,  # type: ignore[arg-type]
+        result = self._config.app.run_command(
+            self._testinfra_command,
             env=self.env,
             debug=self._config.debug,
-            cwd=self._config.scenario.directory,
+            cwd=Path(self._config.scenario.directory),
         )
         if result.returncode == 0:
             msg = "Verifier completed successfully."
@@ -192,17 +234,20 @@ class Testinfra(Verifier):
         else:
             util.sysexit(result.returncode)
 
-    def _get_tests(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
-        """Walk the verifier's directory for tests and returns a list.
+    def _get_tests(self, action_args: list[str] | None = None) -> list[str]:
+        """Walk the verifier's directory for tests.
+
+        Args:
+            action_args: List of paths to search.
 
         Returns:
-            list
+            List of test files.
         """
         if action_args:
             tests = []
             for arg in action_args:
                 args_tests = list(
-                    util.os_walk(  # type: ignore[no-untyped-call]
+                    util.os_walk(
                         os.path.join(self._config.scenario.directory, arg),  # noqa: PTH118
                         "test_*.py",
                         followlinks=True,
@@ -212,7 +257,7 @@ class Testinfra(Verifier):
             return sorted(tests)
         return sorted(
             list(
-                util.os_walk(  # type: ignore[no-untyped-call]
+                util.os_walk(
                     self.directory,
                     "test_*.py",
                     followlinks=True,
@@ -221,7 +266,12 @@ class Testinfra(Verifier):
             + self.additional_files_or_dirs,
         )
 
-    def schema(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def schema(self) -> Schema:
+        """Return validation schema.
+
+        Returns:
+            Verifier schema.
+        """
         return {
             "verifier": {
                 "type": "dict",
